==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/VerticalSeparatorCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { VerticalSeparatorCellInfoDescription } from "./VerticalSeparatorCellInfoDescription";
/**
 * @hidden
 */
export let VerticalSeparatorCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalSeparatorCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalSeparatorCellInfoDescriptionMetadata.a == null) {
                VerticalSeparatorCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalSeparatorCellInfoDescriptionMetadata.c(VerticalSeparatorCellInfoDescriptionMetadata.a);
            }
            if (a.k(VerticalSeparatorCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            VerticalSeparatorCellInfoDescriptionMetadata.b(a);
            a.ac("VerticalSeparatorCellInfo", () => new VerticalSeparatorCellInfoDescription());
            a.ab("VerticalSeparatorCellInfo", VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
    }
    VerticalSeparatorCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(VerticalSeparatorCellInfoDescriptionMetadata, 'VerticalSeparatorCellInfoDescriptionMetadata');
    VerticalSeparatorCellInfoDescriptionMetadata.a = null;
    return VerticalSeparatorCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/VerticalSeparatorCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { VerticalSeparatorCellInfoDescription } from "./VerticalSeparatorCellInfoDescription";
/**
 * @hidden
 */
export let VerticalSeparatorCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class VerticalSeparatorCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (VerticalSeparatorCellInfoDescriptionMetadata.a == null) {
                VerticalSeparatorCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VerticalSeparatorCellInfoDescriptionMetadata.c(VerticalSeparatorCellInfoDescriptionMetadata.a);
            }
            if (a.k(VerticalSeparatorCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            VerticalSeparatorCellInfoDescriptionMetadata.b(a);
            a.ae("VerticalSeparatorCellInfo", () => new VerticalSeparatorCellInfoDescription());
            a.ad("VerticalSeparatorCellInfo", VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
    }
    VerticalSeparatorCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(VerticalSeparatorCellInfoDescriptionMetadata, 'VerticalSeparatorCellInfoDescriptionMetadata');
    VerticalSeparatorCellInfoDescriptionMetadata.a = null;
    return VerticalSeparatorCellInfoDescriptionMetadata;
})();
